==> prize-center-api-1.1.8-sources.jar: cn/com/duiba/prize/center/api/dto/prize/ActivityCommonOptionDto.java <==
package cn.com.duiba.prize.center.api.dto.prize;

import java.io.Serializable;

/**
 * Created by hww on 2018/7/31 下午3:14.
 */
public class ActivityCommonOptionDto implements Serializable {

    private static final long serialVersionUID = -7673180076835418806L;

    /** 主键id */
    private Long id;
    /** 开发者商品id */
    private Long appItemId;
    /** 兑吧商品id */
    private Long itemId;
    /** 奖项类型 */
    private String prizeType;
    /** 奖项名称 */
    private String prizeName;
    /** 面额 */
    private String facePrice;
    /** 概率 */
    private String rate;
    /** 奖项描述 */
    private String description;
    /** 排序 */
    private Integer payload;
    /** 是否隐藏 */
    private Integer hidden;
    /** 保底人数 */
    private Integer minComein;
    /** 用户中奖限制 */
    private Integer winLimit;
    /** 用户中奖限制作用域 */
    private Integer winLimitScope;
    /** logo图 */
    private String logo;
    /**
     * 发奖限制 json格式
     * @see ActivityPrizeOptionLimitDto
     * */
    private String prizesLimit;
    /** 库存 */
    private Long remaining;
    /** 库存中心库存ID  实际库存是通过这个字段扣除的 */
    private String stockId;

    /** 修改的库存时用，表示在原有基础上增加或减少的个数 */
    private Long addOrSubRemaining;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getPrizeName() {
        return prizeName;
    }

    public void setPrizeName(String prizeName) {
        this.prizeName = prizeName;
    }

    public String getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(String facePrice) {
        this.facePrice = facePrice;
    }

    public String getRate() {
        return rate;
    }

    public void setRate(String rate) {
        this.rate = rate;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Integer getPayload() {
        return payload;
    }

    public void setPayload(Integer payload) {
        this.payload = payload;
    }

    public Integer getHidden() {
        return hidden;
    }

    public void setHidden(Integer hidden) {
        this.hidden = hidden;
    }

    public Integer getMinComein() {
        return minComein;
    }

    public void setMinComein(Integer minComein) {
        this.minComein = minComein;
    }

    public Integer getWinLimit() {
        return winLimit;
    }

    public void setWinLimit(Integer winLimit) {
        this.winLimit = winLimit;
    }

    public Integer getWinLimitScope() {
        return winLimitScope;
    }

    public void setWinLimitScope(Integer winLimitScope) {
        this.winLimitScope = winLimitScope;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public String getPrizesLimit() {
        return prizesLimit;
    }

    public void setPrizesLimit(String prizesLimit) {
        this.prizesLimit = prizesLimit;
    }

    public Long getRemaining() {
        return remaining;
    }

    public void setRemaining(Long remaining) {
        this.remaining = remaining;
    }

    public String getStockId() {
        return stockId;
    }

    public void setStockId(String stockId) {
        this.stockId = stockId;
    }

    public Long getAddOrSubRemaining() {
        return addOrSubRemaining;
    }

    public void setAddOrSubRemaining(Long addOrSubRemaining) {
        this.addOrSubRemaining = addOrSubRemaining;
    }
}

==> prize-center-api-1.1.24-20231219.073448-1-sources.jar: cn/com/duiba/prize/center/api/dto/prize/ActivityCommonOptionDto.java <==
package cn.com.duiba.prize.center.api.dto.prize;

import java.io.Serializable;

/**
 * Created by hww on 2018/7/31 下午3:14.
 */
public class ActivityCommonOptionDto implements Serializable {

    private static final long serialVersionUID = -7673180076835418806L;

    /** 主键id */
    private Long id;
    /** 开发者商品id */
    private Long appItemId;
    /** 兑吧商品id */
    private Long itemId;
    /** 奖项类型 */
    private String prizeType;
    /** 奖项名称 */
    private String prizeName;
    /** 面额 */
    private String facePrice;
    /** 概率 */
    private String rate;
    /** 奖项描述 */
    private String description;
    /** 排序 */
    private Integer payload;
    /** 是否隐藏 */
    private Integer hidden;
    /** 保底人数 */
    private Integer minComein;
    /** 用户中奖限制 */
    private Integer winLimit;
    /** 用户中奖限制作用域 */
    private Integer winLimitScope;
    /** logo图 */
    private String logo;
    /**
     * 发奖限制 json格式
     * @see ActivityPrizeOptionLimitDto
     * */
    private String prizesLimit;
    /** 库存 */
    private Long remaining;
    /** 库存中心库存ID  实际库存是通过这个字段扣除的 */
    private String stockId;

    /** 修改的库存时用，表示在原有基础上增加或减少的个数 */
    private Long addOrSubRemaining;

    private String otherUse;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getPrizeName() {
        return prizeName;
    }

    public void setPrizeName(String prizeName) {
        this.prizeName = prizeName;
    }

    public String getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(String facePrice) {
        this.facePrice = facePrice;
    }

    public String getRate() {
        return rate;
    }

    public void setRate(String rate) {
        this.rate = rate;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Integer getPayload() {
        return payload;
    }

    public void setPayload(Integer payload) {
        this.payload = payload;
    }

    public Integer getHidden() {
        return hidden;
    }

    public void setHidden(Integer hidden) {
        this.hidden = hidden;
    }

    public Integer getMinComein() {
        return minComein;
    }

    public void setMinComein(Integer minComein) {
        this.minComein = minComein;
    }

    public Integer getWinLimit() {
        return winLimit;
    }

    public void setWinLimit(Integer winLimit) {
        this.winLimit = winLimit;
    }

    public Integer getWinLimitScope() {
        return winLimitScope;
    }

    public void setWinLimitScope(Integer winLimitScope) {
        this.winLimitScope = winLimitScope;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public String getPrizesLimit() {
        return prizesLimit;
    }

    public void setPrizesLimit(String prizesLimit) {
        this.prizesLimit = prizesLimit;
    }

    public Long getRemaining() {
        return remaining;
    }

    public void setRemaining(Long remaining) {
        this.remaining = remaining;
    }

    public String getStockId() {
        return stockId;
    }

    public void setStockId(String stockId) {
        this.stockId = stockId;
    }

    public Long getAddOrSubRemaining() {
        return addOrSubRemaining;
    }

    public void setAddOrSubRemaining(Long addOrSubRemaining) {
        this.addOrSubRemaining = addOrSubRemaining;
    }

    public String getOtherUse() {
        return otherUse;
    }

    public void setOtherUse(String otherUse) {
        this.otherUse = otherUse;
    }
}
